pwbs
----

.. py:module:: pwbs

This module is place for running pwbs and package initialization.

pwbs.__init__
^^^^^^^^^^^^^

.. py:module:: pwbs.__init__

Place for initialization of the package.

Here is script for running this script by ``python pwbs/__init__.py``.

.. py:function:: pwbs.__init__.main()

    Main function of PWBS

.. py:data:: pwbs.__version__

    Version of the PWBS


pwbs.__main__
^^^^^^^^^^^^^

.. py:module:: pwbs.__main__

Place for running the package.

Here is script for running this script by ``python -m pwbs`` and ``pwbs``.